@@ -11,12 +11,29 @@ import tensorflow as tf  # type: ignore
 T = TypeVar("T", np.ndarray, tf.Tensor)
 
 
+def _sanitise(
+        image: T,
+        bboxes: T,
+        labels: T,
+        convert_fn: Callable[..., T],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
+) -> Tuple[T, T, T]:
+    """
+    Try to convert inputs to the expected format.
+    """
+    image = convert_fn(image)
+    bboxes = reshape_fn(convert_fn(bboxes), (-1, 4))
+    labels = convert_fn(labels)
+    return image, bboxes, labels
+
+
 def _flip_left_right(
         image: T,
         bboxes: T,
         labels: T,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         concat_fn: Callable[[List[T], int], T]
 ) -> Tuple[T, T, T]:
     """
@@ -24,6 +41,10 @@ def _flip_left_right(
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -41,8 +62,9 @@ def _flip_up_down(
         image: T,
         bboxes: T,
         labels: T,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         concat_fn: Callable[[List[T], int], T]
 ) -> Tuple[T, T, T]:
     """
@@ -50,6 +72,10 @@ def _flip_up_down(
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -67,8 +93,9 @@ def _rotate_90(
         image: T,
         bboxes: T,
         labels: T,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         transpose_fn: Callable[[T, Tuple[int, ...]], T],
         concat_fn: Callable[[List[T], int], T]
 ) -> Tuple[T, T, T]:
@@ -79,6 +106,10 @@ def _rotate_90(
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -116,6 +147,7 @@ def _pad(
         labels: T,
         pad_offsets: T,
         shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         pad_image_fn: Callable[[T, T], T],
         concat_fn: Callable[[List[T], int], T]
 ) -> Tuple[T, T, T]:
@@ -127,6 +159,7 @@ def _pad(
     """
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
+    bboxes = reshape_fn(bboxes, (-1, 4))
 
     image = pad_image_fn(image, pad_offsets)
 
@@ -141,8 +174,9 @@ def _rotate_90_and_pad(
         image: T,
         bboxes: T,
         labels: T,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         transpose_fn: Callable[[T, Tuple[int, ...]], T],
         concat_fn: Callable[[List[T], int], T],
         where_fn: Callable[[T, T, T], T],
@@ -157,9 +191,13 @@ def _rotate_90_and_pad(
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image, bboxes, labels = _rotate_90(
         image, bboxes, labels,
-        shape_fn, convert_fn, transpose_fn, concat_fn
+        convert_fn, shape_fn, reshape_fn, transpose_fn, concat_fn
     )
     new_height = convert_fn(shape_fn(image)[0])
     new_width = convert_fn(shape_fn(image)[1])
@@ -178,16 +216,17 @@ def _rotate_90_and_pad(
     )
     return _pad(
         image, bboxes, labels,
-        pad_offsets, shape_fn, pad_image_fn, concat_fn
+        pad_offsets, shape_fn, reshape_fn, pad_image_fn, concat_fn
     )
 
 
-def _affine_transform_single(
+def _affine_transform(
         image: T,
         bboxes: T,
         labels: T,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         expand_dim_fn: Callable[[T, int], T],
         squeeze_fn: Callable[[T, int], T],
         pad_image_fn: Callable[[T, T], T],
@@ -202,7 +241,6 @@ def _affine_transform_single(
         matmul_fn: Callable[[T, T], T],
         clip_fn: Callable[[T, T, T], T],
         gather_image_fn: Callable[[T, T], T],
-        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         copy_fn: Callable[[T], T],
         max_fn: Callable[[T, int], T],
         min_fn: Callable[[T, int], T],
@@ -214,6 +252,10 @@ def _affine_transform_single(
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -349,8 +391,9 @@ def _rotate(
         bboxes: T,
         labels: T,
         angle_deg: float,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         expand_dim_fn: Callable[[T, int], T],
         squeeze_fn: Callable[[T, int], T],
         pad_image_fn: Callable[[T, T], T],
@@ -365,7 +408,6 @@ def _rotate(
         matmul_fn: Callable[[T, T], T],
         clip_fn: Callable[[T, T, T], T],
         gather_image_fn: Callable[[T, T], T],
-        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         copy_fn: Callable[[T], T],
         max_fn: Callable[[T, int], T],
         min_fn: Callable[[T, int], T],
@@ -395,11 +437,12 @@ def _rotate(
         [-sin_fn(ang_rad), cos_fn(ang_rad)]
     ])
 
-    return _affine_transform_single(
-        image, bboxes, labels, shape_fn, convert_fn, expand_dim_fn, squeeze_fn,
-        pad_image_fn, range_fn, round_to_int_fn, repeat_fn, tile_fn,
-        stack_fn, concat_fn, image_dest_rot_mat, bboxes_rot_mat, matmul_fn,
-        clip_fn, gather_image_fn, reshape_fn, copy_fn, max_fn, min_fn,
+    return _affine_transform(
+        image, bboxes, labels, convert_fn, shape_fn, reshape_fn,
+        expand_dim_fn, squeeze_fn, pad_image_fn, range_fn, round_to_int_fn,
+        repeat_fn, tile_fn, stack_fn, concat_fn,
+        image_dest_rot_mat, bboxes_rot_mat, matmul_fn,
+        clip_fn, gather_image_fn, copy_fn, max_fn, min_fn,
         logical_and_fn, boolean_mask_fn
     )
 
@@ -409,8 +452,9 @@ def _shear(
         bboxes: T,
         labels: T,
         angle_deg: float,
-        shape_fn: Callable[[T], Tuple[int, ...]],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         expand_dim_fn: Callable[[T, int], T],
         squeeze_fn: Callable[[T, int], T],
         pad_image_fn: Callable[[T, T], T],
@@ -424,7 +468,6 @@ def _shear(
         matmul_fn: Callable[[T, T], T],
         clip_fn: Callable[[T, T, T], T],
         gather_image_fn: Callable[[T, T], T],
-        reshape_fn: Callable[[T, Tuple[int, ...]], T],
         copy_fn: Callable[[T], T],
         max_fn: Callable[[T, int], T],
         min_fn: Callable[[T, int], T],
@@ -455,11 +498,12 @@ def _shear(
         [convert_fn(0), convert_fn(1)]
     ])
 
-    return _affine_transform_single(
-        image, bboxes, labels, shape_fn, convert_fn, expand_dim_fn, squeeze_fn,
-        pad_image_fn, range_fn, round_to_int_fn, repeat_fn, tile_fn,
-        stack_fn, concat_fn, image_dest_shear_mat, bboxes_shear_mat, matmul_fn,
-        clip_fn, gather_image_fn, reshape_fn, copy_fn, max_fn, min_fn,
+    return _affine_transform(
+        image, bboxes, labels, convert_fn, shape_fn, reshape_fn,
+        expand_dim_fn, squeeze_fn, pad_image_fn, range_fn, round_to_int_fn,
+        repeat_fn, tile_fn, stack_fn, concat_fn,
+        image_dest_shear_mat, bboxes_shear_mat, matmul_fn,
+        clip_fn, gather_image_fn, copy_fn, max_fn, min_fn,
         logical_and_fn, boolean_mask_fn
     )
 
@@ -469,9 +513,10 @@ def _resize(
         bboxes: T,
         labels: T,
         dest_size: Tuple[int, int],
-        shape_fn: Callable[[T], Tuple[int, ...]],
-        resize_image_fn: Callable[[T, Tuple[int, int]], T],
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
+        reshape_fn: Callable[[T, Tuple[int, ...]], T],
+        resize_image_fn: Callable[[T, Tuple[int, int]], T],
         concat_fn: Callable[[List[T], int], T],
 ) -> Tuple[T, T, T]:
     """
@@ -480,6 +525,10 @@ def _resize(
     labels: [0, 1, 0, ...]
     dest_size: (height, width)
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -572,9 +621,9 @@ def _crop(
         offset_width: int,
         cropped_image_height: int,
         cropped_image_width: int,
+        convert_fn: Callable[..., T],
         shape_fn: Callable[[T], Tuple[int, ...]],
         reshape_fn: Callable[[T, Tuple[int, ...]], T],
-        convert_fn: Callable[..., T],
         concat_fn: Callable[[List[T], int], T],
         logical_and_fn: Callable[[T, T], T],
         squeeze_fn: Callable[[T, int], T],
@@ -588,6 +637,10 @@ def _crop(
     offset_height: in range [0, image_height - 1]
     offset_width: in range [0, image_width - 1]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -605,7 +658,6 @@ def _crop(
     image = image[int(top):int(bottom), int(left):int(right), :]
 
     # Translate bboxes values.
-    bboxes = reshape_fn(bboxes, (-1, 4))
     xs = bboxes[:, :1] - offset_width
     ys = bboxes[:, 1:2] - offset_height
     widths = bboxes[:, 2:3]
@@ -642,9 +694,9 @@ def _translate(
         labels: T,
         translate_height: int,
         translate_width: int,
+        convert_fn: Callable[..., T],
         shape_fn: Callable[[T], Tuple[int, ...]],
         reshape_fn: Callable[[T, Tuple[int, ...]], T],
-        convert_fn: Callable[..., T],
         where_fn: Callable[[T, T, T], T],
         abs_fn: Callable[[T], T],
         concat_fn: Callable[[List[T], int], T],
@@ -663,6 +715,10 @@ def _translate(
     translate_height: in range [-image_height + 1: image_height - 1]
     translate_width: in range [-image_width + 1: image_width - 1]
     """
+    image, bboxes, labels = _sanitise(
+        image, bboxes, labels, convert_fn, reshape_fn
+    )
+
     image_shape = shape_fn(image)
     assert len(image_shape) == 3
 
@@ -689,7 +745,7 @@ def _translate(
     image, bboxes, labels = _crop(
         image, bboxes, labels,
         offset_height, offset_width, cropped_height, cropped_width,
-        shape_fn, reshape_fn, convert_fn, concat_fn, logical_and_fn,
+        convert_fn, shape_fn, reshape_fn, concat_fn, logical_and_fn,
         squeeze_fn, clip_fn, boolean_mask_fn
     )
 
