@@ -2,7 +2,7 @@
 API for Numpy usage.
 """
 
-from typing import Any, Callable, Tuple
+from typing import Any, Callable, Optional, Tuple
 
 import numpy as np  # type: ignore
 
@@ -39,7 +39,7 @@ def flip_left_right(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _flip_left_right(
         image, bboxes, labels,
-        np.shape, _np_convert, np.concatenate
+        _np_convert, np.shape, np.reshape, np.concatenate
     )
 
 
@@ -50,7 +50,7 @@ def flip_up_down(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _flip_up_down(
         image, bboxes, labels,
-        np.shape, _np_convert, np.concatenate
+        _np_convert, np.shape, np.reshape, np.concatenate
     )
 
 
@@ -61,8 +61,8 @@ def resize(
         dest_size: Tuple[int, int]
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _resize(
-        image, bboxes, labels,
-        dest_size, np.shape, _np_resize_image, _np_convert, np.concatenate
+        image, bboxes, labels, dest_size,
+        _np_convert, np.shape, np.reshape, _np_resize_image, np.concatenate
     )
 
 
@@ -73,7 +73,7 @@ def rotate_90(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _rotate_90(
         image, bboxes, labels,
-        np.shape, _np_convert, np.transpose, np.concatenate
+        _np_convert, np.shape, np.reshape, np.transpose, np.concatenate
     )
 
 
@@ -84,7 +84,7 @@ def rotate_90_and_pad(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _rotate_90_and_pad(
         image, bboxes, labels,
-        np.shape, _np_convert, np.transpose, np.concatenate,
+        _np_convert, np.shape, np.reshape, np.transpose, np.concatenate,
         np.where, np.ceil, np.floor, _np_pad_image
     )
 
@@ -97,11 +97,11 @@ def rotate(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _rotate(
         image, bboxes, labels, angle_deg,
-        np.shape, _np_convert, np.expand_dims, np.squeeze,
+        _np_convert, np.shape, np.reshape, np.expand_dims, np.squeeze,
         _np_pad_image, _np_range, _np_round_to_int, np.repeat, np.tile,
         np.stack, np.concatenate, np.cos, np.sin, np.matmul, np.clip,
-        _np_gather_image, np.reshape, np.copy,
-        np.max, np.min, _np_logical_and, _np_boolean_mask
+        _np_gather_image, np.copy, np.max, np.min,
+        _np_logical_and, _np_boolean_mask
     )
 
 
@@ -113,11 +113,11 @@ def shear(
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     return _shear(
         image, bboxes, labels, angle_deg,
-        np.shape, _np_convert, np.expand_dims, np.squeeze,
+        _np_convert, np.shape, np.reshape, np.expand_dims, np.squeeze,
         _np_pad_image, _np_range, _np_round_to_int, np.repeat, np.tile,
         np.stack, np.concatenate, np.tan, np.matmul, np.clip,
-        _np_gather_image, np.reshape, np.copy,
-        np.max, np.min, _np_logical_and, _np_boolean_mask
+        _np_gather_image, np.copy, np.max, np.min,
+        _np_logical_and, _np_boolean_mask
     )
 
 
@@ -147,7 +147,7 @@ def crop(
         image, bboxes, labels,
         offset_height, offset_width,
         cropped_image_height, cropped_image_width,
-        np.shape, np.reshape, _np_convert, np.concatenate,
+        _np_convert, np.shape, np.reshape, np.concatenate,
         _np_logical_and, np.squeeze, np.clip, _np_boolean_mask
     )
 
@@ -162,7 +162,7 @@ def translate(
     return _translate(
         image, bboxes, labels,
         translate_height, translate_width,
-        np.shape, np.reshape, _np_convert, np.where, np.abs, np.concatenate,
+        _np_convert, np.shape, np.reshape, np.where, np.abs, np.concatenate,
         _np_logical_and, np.squeeze, np.clip, _np_boolean_mask, _np_pad_image
     )
 
@@ -187,7 +187,7 @@ class RandomTransform:
             self,
             np_fn: Callable[..., Tuple[np.ndarray, np.ndarray, np.ndarray]],
             probability: float,
-            seed: int,
+            seed: Optional[int],
     ) -> None:
         self._np_fn = np_fn
         self.probability = probability
@@ -217,7 +217,7 @@ class RandomFlipLeftRight(RandomTransform):
     def __init__(
             self,
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(flip_left_right, probability, seed)
 
@@ -237,7 +237,7 @@ class RandomFlipUpDown(RandomTransform):
     def __init__(
             self,
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(flip_up_down, probability, seed)
 
@@ -257,7 +257,7 @@ class RandomRotate90(RandomTransform):
     def __init__(
             self,
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(rotate_90, probability, seed)
 
@@ -277,7 +277,7 @@ class RandomRotate90AndPad(RandomTransform):
     def __init__(
             self,
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(rotate_90_and_pad, probability, seed)
 
@@ -298,7 +298,7 @@ class RandomRotate(RandomTransform):
             self,
             angle_deg_range: Tuple[float, float] = (-15.0, 15.0),
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(rotate, probability, seed)
         assert angle_deg_range[0] < angle_deg_range[1]
@@ -326,7 +326,7 @@ class RandomShear(RandomTransform):
             self,
             angle_deg_range: Tuple[float, float] = (-15.0, 15.0),
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(shear, probability, seed)
         assert -90.0 < angle_deg_range[0] < angle_deg_range[1] < 90.0
@@ -352,10 +352,10 @@ class RandomCrop(RandomTransform):
 
     def __init__(
             self,
-            crop_height_fraction_range: Tuple[float, float] = (0.6, 0.9),
-            crop_width_fraction_range: Tuple[float, float] = (0.6, 0.9),
+            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(crop, probability, seed)
         self.crop_height_fraction_range = crop_height_fraction_range
@@ -388,10 +388,10 @@ class RandomTranslate(RandomTransform):
 
     def __init__(
             self,
-            translate_height_fraction_range: Tuple[float, float] = (-0.2, 0.2),
-            translate_width_fraction_range: Tuple[float, float] = (-0.2, 0.2),
+            translate_height_fraction_range: Tuple[float, float] = (-0.1, 0.1),
+            translate_width_fraction_range: Tuple[float, float] = (-0.1, 0.1),
             probability: float = 0.7,
-            seed: int = 0
+            seed: Optional[int] = None
     ) -> None:
         super().__init__(translate, probability, seed)
         self.translate_height_fraction_range = translate_height_fraction_range
